
.. _GitHub python-rope / rope: https://github.com/python-rope/rope


========================================
 rope, a python refactoring library ...
========================================


Overview
========

`Rope`_ is a python refactoring library.

.. _`rope`: https://github.com/python-rope/rope


Notes
============

* Nick Smith <nicks@fastmail.fm> takes over maintaining rope. Many thanks to
  Matěj Cepl for his work maintaining rope for the past few years!!
* Full python3 support is in progress... stay tuned

Getting Started
===============

* List of features: `<docs/rope.rst>`_
* Overview of some of rope's features: `<docs/overview.rst>`_
* Using as a library: `<docs/library.rst>`_
* Contributing: `<docs/contributing.rst>`_

To change your project preferences edit
``$PROJECT_ROOT/.ropeproject/config.py`` where ``$PROJECT_ROOT`` is
the root folder of your project (this file is created the first time
you open a project).


Bug Reports
===========

Send your bug reports and feature requests to `rope-dev (at)
googlegroups.com`_.

.. _`rope-dev (at) googlegroups.com`: http://groups.google.com/group/rope-dev


License
=======

This program is under the terms of GPL v2 (GNU General Public License).
Have a look at `COPYING`_ for more information.


.. _`docs/rope.rst`: docs/rope.html
.. _`docs/overview.rst`: docs/overview.html
.. _`docs/contributing.rst`: docs/contributing.html
.. _`docs/library.rst`: docs/library.html
.. _`COPYING`: COPYING

.. image:: https://secure.travis-ci.org/python-rope/rope.png
   :alt: Build Status
